# pyOSut
Python implementation of the _OSut_ Ruby gem for the OpenStudio SDK.

- PyPi [package](https://pypi.org/project/osut/)
- Ruby [gem](https://rubygems.org/gems/osut)
- Ruby GitHub [repository](https://github.com/rd2/osut)

----

_OSut_ interacts with _OpenStudio_:

`pip install openstudio`

----

To download the _OSut_ Python package:

`pip install --upgrade osut`

----

To import the _OSut_ module in a Python project:

`from osut import osut`

____

To run the _OSut_ unit tests on a `git clone` of the repo:

`python -m unittest`
